#
#  Build Binutils
#

DESC="Build Binutils for PowerPC"

#  Source and patches
BINVER=binutils-2.16
SRC=$BINVER.tar.bz2
PATCHES=binutils-patches

CFLAGS="-O2 -g"

. common.sh

TARGET=powerpc-eabi
BLDDIR=$BLDDIR/bld_bin
SYSROOT=$RELDIR/$TARGET
BINDIR=$RELDIR/bin
SRCDIR=$SRCDIR/binutils
BIN_SRC_DIR=$BLDDIR/binutils
SYSROOT=$RELDIR

echo "Building PowerPC Binutils"
echo "Version $BINVER"
echo "Current directory is $CURDIR"
echo "Platform is $PLATFORM"

rm -rf $BLDDIR/binutils
rm -rf $BLDDIR/build
rm -rf $BLDDIR/log
mkdir -p $BLDDIR/build
mkdir -p $BLDDIR/log

if [ ! -d $RELDIR ]; then mkdir -p $RELDIR; fi

errors=0

#  Unpack and patch sources
echo "Unpacking binutils sources"
(cd $BLDDIR; tar xfj $SRCDIR/$SRC; mv $BINVER binutils)

# Read and apply patches in proper directory
while read DIR PATCH COMMENT; do
   case $DIR in
      \#*) ;;
      stop)
	  echo "stop encountered -- terminating patches"
	  break
	  ;;
      *)  
          echo -n "Applying patch $PATCH"
          cd $BLDDIR/$DIR
	  if [ -f $SRCDIR/$PATCH ]; then
            patch -F0 -p1 < $SRCDIR/$PATCH > $BLDDIR/log/$PATCH.log 2>&1 
            rc=$?
            echo " -- rc=$rc"
            if [ $rc != 0 ]; then errors=1; fi
	  else
	    echo " -- missing"
	    errors=1
	  fi
	  ;;
   esac
done < $SRCDIR/$PATCHES

if [ $errors != 0 ]; then
   echo ""
   echo "Exiting because of previous errors"
   echo ""
   exit
fi

#  Add Xilinx version info - copied to all executables
cd $BLDDIR/binutils
sed -e "s/PACKAGE_VERSION=\([0-9.]*\)/PACKAGE_VERSION=\"\1 $XILINX_VERSION\"/" configure > configure.new
mv configure configure.orig
mv configure.new configure
chmod a+x configure

#  Create build directory
cd $BLDDIR/build

echo -n "Configuring Binutils"
$BIN_SRC_DIR/configure 				\
	--target=powerpc-eabi 			\
	--prefix=$RELDIR 			\
	--program-prefix="powerpc-eabi-" 	\
        --with-sysroot=$SYSROOT                 \
	--with-cpu=405				\
		> $BLDDIR/log/binutils-config.log 2>&1 
  rc=$?
  echo " -- rc=$rc"
  if [ $rc != 0 ]; then errors=1; fi

if [ $NOBUILD = 0 ]; then 
  echo -n "Compiling Binutils"
  $MAKE all CFLAGS="$CFLAGS"			\
		> $BLDDIR/log/binutils-make.log 2>&1
  rc=$?
  echo -n "   make -- rc=$rc"
  if [ $rc != 0 ]; then errors=1; fi
  $MAKE install	CFLAGS="$CFLAGS"		\
		> $BLDDIR/log/binutils-install.log 2>&1
  rc=$?
  echo  "   install -- rc=$rc"
  if [ $rc != 0 ]; then errors=1; fi
fi

echo -n "Configuring Gprof"
mkdir -p gprof
cd gprof
$BIN_SRC_DIR/gprof/configure			\
	--target=powerpc-eabi 			\
	-prefix=$RELDIR 			\
	-program-prefix="powerpc-eabi-" 	\
	-v --with-cpu=405			\
		> $BLDDIR/log/gprof-config.log 2>&1
  rc=$?
  echo " -- rc=$rc"
  if [ $rc != 0 ]; then errors=1; fi

if [ $NOBUILD = 0 ]; then 
  echo -n "Compiling Gprof"
  $MAKE all CFLAGS="$CFLAGS"			\
		> $BLDDIR/log/gprof-make.log 2>&1
  rc=$?
  echo -n "   make -- rc=$rc"
  if [ $rc != 0 ]; then errors=1; fi
  $MAKE install	CFLAGS="$CFLAGS"		\
		> $BLDDIR/log/gprof-install.log 2>&1
  rc=$?
  echo  "   install -- rc=$rc"
  if [ $rc != 0 ]; then errors=1; fi
fi

cd $BLDDIR/..
if [ $NOCLEAN = 0 ]; then
  rm -rf $BLDDIR
fi

if [ $errors != 0 ]; then
  echo "PowerPC Binutils Build FAILED"
else
  echo "PowerPC Binutils Build Done"
fi
