#
#  Build GDB
#

DESC="Build GDB for PowerPC"

#  Source and patches
#GDBVER=insight-6.5
#SRC=insight-6.5.tar.bz2
GDBVER=gdb-6.5
SRC=gdb-6.5.tar.gz

PATCHES=gdb-patches-non-insight

. common.sh

CFLAGS="-g -O2"

BLDDIR=$BLDDIR/bld_gdb
BINDIR=$RELDIR/bin
GDB_SRC_DIR=$BLDDIR/gdb
SRCDIR=$SRCDIR/gdb

echo "Building PowerPC GDB"
echo "Platform is $PLATFORM"
echo "Environment directory is $CURDIR"

rm -rf $BLDDIR/gdb
rm -rf $BLDDIR/build
rm -rf $BLDDIR/log
mkdir -p $BLDDIR/build
mkdir -p $BLDDIR/log

if [ ! -d $RELDIR ]; then mkdir -p $RELDIR; fi

echo "Unpacking gdb sources"
(cd $BLDDIR; tar xfz $SRCDIR/$SRC; mv $GDBVER gdb)

#  Unpack and patch sources
while read DIR PATCH COMMENT; do
   case $DIR in
      \#*) ;;
      *)  
          echo -n "Applying patch $PATCH"
          cd $BLDDIR/$DIR
	  if [ -f $SRCDIR/$PATCH ]; then
            patch -F0 -p1 < $SRCDIR/$PATCH > $BLDDIR/log/$PATCH.log 2>&1 
            rc=$?
            echo " -- rc=$rc"
            if [ $rc != 0 ]; then errors=1; fi
	  else
	    echo " -- missing"
	    errors=1
	  fi
	  ;;
   esac
done < $SRCDIR/$PATCHES

#  Set Xilinx version
cd gdb
sed -e "s/\([0-9]*\.[0-9]*\.[0-9]*\).*$/\1 $XILINX_VERSION/" version.in > version.new
mv version.in version.in.old
mv version.new version.in

#  Create build directory
cd $BLDDIR/build

PATH=$BINDIR:$PATH

echo -n "Configuring GDB"
../gdb/configure 				\
	--target=powerpc-eabi 			\
	--prefix=$RELDIR 			\
	--program-prefix="powerpc-eabi-" 	\
	--with-cpu=405				\
	--with-cpu=440				\
		> $BLDDIR/log/gdb-config.log 2>&1 
   echo " -- rc=$?"

if [ $NOBUILD = 0 ]; then
  echo -n "Compiling GDB"
  $MAKE all CFLAGS="$CFLAGS"			\
		> $BLDDIR/log/gdb-make.log 2>&1
     echo -n "   make -- rc=$?"
  $MAKE install CFLAGS="$CFLAGS"		\
		> $BLDDIR/log/gdb-install.log 2>&1
     echo "   install -- rc=$?"
fi

if [ $NOCLEAN == 0 ]; then
  rm -rf $BLD_DIR
fi

echo "PowerPC GDB Build Done"

   


